@@ -44,16 +44,18 @@ class markdownTable():
         self.padding_char = ' '
         self.newline_char = '\n'
         self.float_rounding = 2
+        self.quote = True
         self.updateMetaParams()
         return
 
-    def setParams(self, row_sep='always', padding_width=0, padding_weight='centerleft', padding_char=' ', newline_char='\n', float_rounding=2):
+    def setParams(self, row_sep='always', padding_width=0, padding_weight='centerleft', padding_char=' ', newline_char='\n', float_rounding=2, quote=True):
         self.row_sep = row_sep
         self.padding_width = padding_width
         self.padding_weight = padding_weight
         self.padding_char = padding_char
         self.newline_char = newline_char
         self.float_rounding = float_rounding
+        self.quote = quote
         self.updateMetaParams()
         return self
 
@@ -111,11 +113,15 @@ class markdownTable():
         return right
 
     def getMarkdown(self):
-        return '```'+self.getHeader()+self.getBody()+'```'
+        data = self.getHeader()+self.getBody()
+        if self.quote:
+            return '```'+data+'```'
+        else:
+            return data
 
     def getHeader(self):
         header = ''
-        if self.row_sep == 'topbottom' or 'always':
+        if self.row_sep in ('topbottom', 'always'):
             header += self.newline_char + self.var_row_sep_last + self.newline_char
         for key in self.data[0].keys():
             margin = self.var_padding[key]-len(key)
@@ -124,6 +130,8 @@ class markdownTable():
         header += '|' + self.newline_char
         if self.row_sep == 'always':
             header += self.var_row_sep + self.newline_char
+        if self.row_sep == 'markdown':
+            header += self.var_row_sep.replace('+', '|') + self.newline_char
         return header
 
     def getBody(self):
